/**
 * @license
 * Visual Blocks Editor
 *
 * Copyright 2012 Google Inc.
 * https://developers.google.com/blockly/
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * @fileoverview dbkBlocks On Blockly.
 * @author Rubens Queiroz
 */
'use strict';

goog.provide('Blockly.Blocks.atuadores');
goog.require('Blockly.Blocks');

/** Com o LED BRANCO
*Blockly.FieldColour.COLOURS = ['#0f0','#ff0','#f00','#fff'];
*Blockly.FieldColour.COLUMNS = 4;
*/

Blockly.FieldColour.COLOURS = ['#0f0','#ff0','#f00','#00f'];
Blockly.FieldColour.COLUMNS = 4;

var cor_bloco_led = 160;
var cor_ledRGB = 95;
var cor_motor = 196;
var cor_servo = 174;
var cor_lcd = 328;
var cor_7Seg = 315; 
var cor_buzzer = 240; 


Blockly.Blocks['acender_led'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_bloco_led);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/led_on.png", 40, 40, "*"))
        .appendField("Acender o LED")
        .appendField(new Blockly.FieldColour("#ff0000"), "cor_led");
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Acende o LED com a cor indicada.');
  }
};

Blockly.Blocks['apagar_led'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(140);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/led_off_long.png", 48, 40, "*"))
        .appendField("Apagar o LED")
        .appendField(new Blockly.FieldColour("#ff0000"), "cor_led");
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Apaga o LED com a cor indicada.');
  }
};

Blockly.Blocks['girar_motor'] = {
  init: function() {
	var val_1 = '\u25CF' + "  " + "Devagar";
	var val_2 = '\u25CE' + "  " + "Velocidade Média";
    var val_3 = '\u25CB' + "  " + "Rápido";
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_motor);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/motor_move_2.png", 40, 40, "*"))
        .appendField("Girar Motor DC")
        .appendField(new Blockly.FieldDropdown([[val_3, "high"],[val_2, "middle"],[val_1, "low"]]), "velocidade_motor");    
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o motor DC girar na velocidade indicada.');
  }
};

Blockly.Blocks['parar_motor'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_motor);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/helice.png", 40, 40, "*"))
		.appendField("Parar Motor DC")
		.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/invisible.png", 63, 40, "*"));
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o Motor DC  parar');
  }
};

/**Blockly.Blocks['mover_servomotor'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_servo);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/servo_move.png", 40, 40, "*"))
        .appendField("Mover Servo Motor para")
        .appendField(new Blockly.FieldDropdown([["Direita", "0"],["Frente", "80"], ["Esquerda","180"]]), "posicao_ponteiro_servo")
		.appendField("graus");
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o ponteiro do Servo Motor mover-se para a posição indicada');
  }
}; */

/**Blockly.Blocks['mover_servomotor'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_servo);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/servo_move.png", 40, 40, "*"))
        .appendField("Mover Servo Motor para")
        .appendField(new Blockly.FieldDropdown([["0", "0"], ["30", "30"],["60", "60"],["90", "90"], ["120", "120"], ["150", "150"],["180", "180"]]), "posicao_ponteiro_servo")
		.appendField("graus");
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o ponteiro do Servo Motor mover-se para a posição indicada');
  }
}; **/

Blockly.Blocks['mover_servomotor'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_servo);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/servo_move.png", 40, 40, "*"))
        .appendField("Mover Servo Motor para")
        .appendField(new Blockly.FieldAngle(90), "posicao_ponteiro_servo")
		.appendField("graus");
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o ponteiro do Servo Motor mover-se para a posição indicada');
  }
}; 

Blockly.Blocks['escrever_lcd'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_lcd);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/lcd4.png", 40, 40, "*"))
        .appendField("Escrever")
        .appendField(new Blockly.FieldTextInput("Oi"), "texto")
        .appendField("na")
        .appendField(new Blockly.FieldDropdown([["linha 1", "1"], ["linha 2", "2"]]), "numero_linha");
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Escreve um texto no display de LCD na linha indicada (Máximo de 16 letras e espaços em cada linha)');
  }
};

Blockly.Blocks['limpar_lcd'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_lcd);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/limpar_lcd4.png", 40, 40, "*"))
		.appendField("Limpar Display")
		.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/invisible.png", 70, 40, "*"));
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Limpa o texto das duas linhas do discplay de LCD');
  }
  
};

Blockly.Blocks['escrever_display_7s']={
init:function(){
this.setHelpUrl('http://www.example.com/');
this.setColour(cor_7Seg);
this.appendDummyInput()
.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/display7SegOn.png", 40, 40, "*"))
.appendField("Escrever ")
.appendField(new Blockly.FieldDropdown([["0","0"],["1","1"],["2","2"],["3","3"],["4","4"],["5","5"],["6","6"],["7","7"],["8","8"],["9","9"]]),"numerosD7S")
.appendField("no Display de 7 Segmentos");
this.setPreviousStatement(true);
this.setNextStatement(true);
this.setTooltip('');
}
};


Blockly.Blocks['limpar_display_7s']={
init:function(){
this.setHelpUrl('http://www.example.com/');
this.setColour(cor_7Seg);
this.appendDummyInput()
.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/display7SegOff.png", 40, 40,"*"))
.appendField("Limpar Display de 7 Segmentos")
.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/invisible.png", 63, 40, "*"));
this.setPreviousStatement(true);
this.setNextStatement(true);
this.setTooltip('');
}
};


Blockly.Blocks['led_rgb'] = {
  init: function() {
var colourRed = new Blockly.FieldColour('#ffffff');
colourRed.setColours(['#f00','#fff']).setColumns(2);
var colourGreen = new Blockly.FieldColour('#ffffff');
colourGreen.setColours(['#0f0','#fff']).setColumns(2);
var colourBlue = new Blockly.FieldColour('#ffffff');
colourBlue.setColours(['#00f','#fff']).setColumns(2); 
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_ledRGB);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/led_RGB.png", 40, 40, "*"))
        .appendField("Acender Luz  ")
		.appendField(colourRed, "luzVermelha")
		.appendField(colourGreen, "luzVerde")
		.appendField(colourBlue, "luzAzul")
        .appendField(" do LED RGB");
    this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('');
  }
}; 


Blockly.Blocks['tocar_nota_buzzer'] = {
  init: function() {
    this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_buzzer);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/buzzer_notas.png", 40, 40, "*"))
        .appendField("Tocar nota")
        .appendField(new Blockly.FieldDropdown([["Dó", "262"], ["Ré", "294"], ["Mi", "329"],
												["Fá", "349"], ["Sol", "392"], ["Lá", "440"],
												["Si", "494"]]), "nota_musical")											
	    .appendField("no Buzzer")
		.appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/invisible.png", 26, 40, "*"));		
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o buzzer tocar a nota especificada');
  }
};

Blockly.Blocks['tocar_sirene_buzzer'] = {
  init: function() {
	var val_1 = '\u25CF' + "  " + "Lento";
	var val_2 = '\u25CB' + "  " + "Rápido";
	this.setHelpUrl('http://www.example.com/');
    this.setColour(cor_buzzer);
    this.appendDummyInput()
        .appendField(new Blockly.FieldImage("../blockly/blocks/db4k/icons/buzzer_sirente.png", 40, 40, "*"))
        .appendField("Tocar Sirene")
        .appendField(new Blockly.FieldDropdown([[val_2, "0"],[val_1, "1"]]), "velocidade")
	    .appendField("no Buzzer");  		
	this.setPreviousStatement(true);
    this.setNextStatement(true);
    this.setTooltip('Faz o buzzer tocar sirene na velocidade especificada');
  }
};


